from dnv_bladed_results import *

############   Bladed Results API: Get variable metadata   ############

# Demonstrates how to get metadata data from:
# - 1D variables (dependent variables with one independent variable)
# - 2D variables (dependent variables with two independent variables)


def display_variable_info(directory, run_name, variable_name):

    try:

        ################################
        #  Get a specific run by name  #
        ################################

        run = ResultsApi.get_run(directory, run_name)

        ###############################
        #  Display variable metadata  #
        ###############################
    
        # Get 1D or 2D variable depending on which type is found
        if run.contains_variable_1d(variable_name):
            variable = run.get_variable_1d(variable_name)
        elif run.contains_variable_2d(variable_name):
            variable = run.get_variable_2d(variable_name)
        else:
            print("\nRun does not contain variable with name '" + variable_name + "'!")
            return

        #######################
        #  Basic information  #
        #######################

        print("\nVariable name is '" + variable.get_name() + "'")
        print("Variable quantity code is '" + variable.get_quantity_code() + "'")
        print("Variable SI unit is '" + variable.get_siunit() + "'")
        print("Simulation length = " + str(variable.get_time_domain_simulation_length()) + " seconds")

        ######################
        #  Data information  #
        ######################

        print("Data contains " + str(variable.get_data_point_count()) + " points")

        if variable.get_data_type() == VARIABLE_DATA_TYPE_FLOAT32:
            # Note: NumPy single precision appears to be slightly lower resolution than native single precision, whereas double precision matches exactly
            print("Data is single precision")
        else:
            print("Data is double precision")

        if variable.get_data_format() == VARIABLE_DATA_FORMAT_BINARY:
            print("Data format is binary")
        else:
            print("Data format is ASCII")

        ######################################
        #  Independent variable information  #
        ######################################
        
        print("Variable has " + str(variable.get_number_of_independent_variables()) + " independent variable(s)")
        ind_vars = variable.get_independent_variables()
        ind_var: IndependentVariable
        i = 1
        for ind_var in ind_vars:
            print("    Independent variable " + str(i) + " name is '" + ind_var.get_name() + "'")
            print("    Independent variable " + str(i) + " unit is '" + ind_var.get_siunit() + "'")
            if ind_var.get_axis_type() == AXIS_TYPE_ID_INTERVAL_AXIS:
                print("    Independent variable " + str(i) + " axis type is interval")
            elif ind_var.get_axis_type() == AXIS_TYPE_ID_LABELLED_STRING_AXIS:
                print("    Independent variable " + str(i) + " axis type is labelled string")
                print("    Independent variable " + str(i) + " values:" + str(ind_var.get_values_as_string()))
            else:
                print("    Independent variable " + str(i) + " axis type is labelled number")
                print("    Independent variable " + str(i) + " values:" + str(ind_var.get_values_as_string()))
            i = i + 1

        ##############################
        #  Parent group information  #
        ##############################

        print("Variable parent group name is '" + variable.get_parent_group_name() + "'")
        print("Variable parent group path is '" + variable.get_parent_group_header_file_full_path() + "'")
        print("Variable parent group number is", variable.get_parent_group_number())
        print()

    except RuntimeError as e:
        print(e)


# 1D variable
display_variable_info("./Runs/demo/powprod5MW", "powprod5MW", "Rotating hub Mx")

# 2D variable
display_variable_info("./Runs/demo/powprod5MW", "powprod5MW", "Tower Mx")
